@@ -65,7 +65,6 @@ class ChessDaskCluster:
         tasks_for_game = ChessUtil.generate_ply_info_list_for_game(game)
         worker_client = get_client()
         task_futures = worker_client.map(ChessUtil.find_control_for_square, tasks_for_game["ply_info_list"])
-        secede()
         game_data = None
         try:
             wait(task_futures, timeout)
@@ -74,7 +73,6 @@ class ChessDaskCluster:
             game_data["filename"] = str(game_no) + " " + game.headers["Event"]
         except TimeoutError:
             print("Game timed out: " + str(game_no))
-        rejoin()
         return game_data
 
     def __init__(self):
@@ -126,12 +124,21 @@ class ChessDaskCluster:
         results = []
         for game in game_list:
             game_futures.append(self.client.submit(ChessDaskCluster.run_in_parallel,
-                                                   *(game, game_no)), self.config_values["timeout_per_game"])
+                                                   *(game, game_no), self.config_values["timeout_per_game"]))
             game_no = game_no + 1
             if game_no % self.config_values["game_batch_size"] == 0:
-                results.extend(self.client.gather(game_futures))
-                game_futures = []
+                for future in game_futures:
+                    try:
+                        result = future.result(self.config_values["timeout_per_game"])
+                        results.append(result)
+                    except TimeoutError:
+                        print("Game timed out")
                 print("Completed till " + str(game_no))
-        results.extend(self.client.gather(game_futures))
+        for future in game_futures:
+            try:
+                result = future.result(self.config_values["timeout_per_game"])
+                results.append(result)
+            except TimeoutError:
+                print("Game timed out")
         print("Completed all")
         return results
